"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _CodeEditorDialog = _interopRequireDefault(require("./components/CodeEditorDialog"));

var _highlight = _interopRequireDefault(require("highlight.js"));

require("./styles/codeblock.css");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var isCodeBlock = function isCodeBlock(node) {
  return node && node.nodeName == 'PRE';
};

var _default = function _default(editor, pluginUrl) {
  var $ = editor.$;
  var dialog = new _CodeEditorDialog["default"](editor);
  editor.addCommand('codeblock', function () {
    dialog.open();
  });
  editor.ui.registry.addButton('codeblock', {
    icon: 'code-sample',
    tooltip: '코드블럭',
    stateSelector: 'pre',
    onAction: function onAction() {
      editor.execCommand('codeblock');
    }
  });
  editor.on('PreProcess', function (e) {
    $('pre[contenteditable=false]', e.node).each(function (idx, elm) {
      if (!isCodeBlock(elm)) {
        return;
      }

      var $elm = $(elm),
          code = elm.textContent;
      var language = $elm.attr('data-language');
      $elm.removeAttr('data-language');
      $elm.removeAttr('contentEditable');
      var codeClass = language ? " class=\"".concat(language, "\"") : '';
      $elm.empty().removeAttr('class').append($("<code".concat(codeClass, "></code>")).each(function (idx, elm) {
        elm.textContent = code;
      }));
    });
  });
  editor.on('SetContent', function () {
    var unprocessedCodeSamples = $('pre').filter(function (idx, elm) {
      return isCodeBlock(elm);
    }).filter(function (idx, elm) {
      return elm.contentEditable !== "false";
    });

    if (unprocessedCodeSamples.length) {
      editor.undoManager.transact(function () {
        unprocessedCodeSamples.each(function (idx, elm) {
          var $elm = $(elm);
          $elm.find('br').each(function (idx, br) {
            br.parentNode.replaceChild(editor.getDoc().createTextNode('\n'), br);
          });
          var codes = $elm.find("code[class]");

          if (codes.length > 0) {
            codes.each(function (idx, code) {
              if (code.getAttribute('class')) {
                $elm.attr('data-language', code.getAttribute('class'));
              }

              _highlight["default"].highlightBlock(code);
            });
          } else {
            _highlight["default"].highlightBlock(elm);
          }

          $elm.attr('contentEditable', false);
        });
      });
    }
  });
  editor.on('init', function () {
    if (editor.settings.codeblock && editor.settings.codeblock.highlightStyle) {
      var linkElm = editor.dom.create('link', {
        rel: 'stylesheet',
        href: editor.settings.codeblock.highlightStyle
      });
      editor.getDoc().getElementsByTagName('head')[0].appendChild(linkElm);
    }
  });
};

exports["default"] = _default;