"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _codemirror = _interopRequireDefault(require("codemirror/lib/codemirror"));

var _highlight = _interopRequireDefault(require("highlight.js"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function adjustLanguage(lang) {
  if (lang) {
    return lang.replace('lang-', '').replace('language-', '');
  } else {
    return '';
  }
}

var CodeEditor = /*#__PURE__*/function () {
  function CodeEditor(tinymceEditor, textarea, languageSelect) {
    _classCallCheck(this, CodeEditor);

    this.language = '';
    this.tinymceEditor = tinymceEditor;
    this.textarea = textarea;
    this.languageSelect = languageSelect;
    this.codeMirror = null;
    this.init();
  }

  _createClass(CodeEditor, [{
    key: "init",
    value: function init() {
      var _this = this;

      var _this$tinymceEditor = this.tinymceEditor,
          $ = _this$tinymceEditor.$,
          dom = _this$tinymceEditor.dom,
          settings = _this$tinymceEditor.settings;
      var theme = 'default';
      this.langs = [];

      if (settings.codeblock) {
        if (settings.codeblock.codeTheme) {
          theme = settings.codeblock.codeTheme;
        }

        if (settings.codeblock.langs) {
          this.langs = settings.codeblock.langs;
        }
      }

      if (this.textarea && _codemirror["default"] && _codemirror["default"].fromTextArea) {
        this.codeMirror = _codemirror["default"].fromTextArea(this.textarea, {
          lineNumbers: true,
          autofocus: true,
          theme: theme
        });
      }

      if (this.languageSelect) {
        this.langs.forEach(function (item) {
          dom.add(_this.languageSelect, 'option', {
            value: item.value
          }, item.label);
        });
        $(this.languageSelect).on('change', function (e) {
          _this.setLanguage(e.target.value);
        });
      }
    }
  }, {
    key: "refresh",
    value: function refresh() {
      this.selectedNode = null;
      var currentCode = this.getCurrentCode();

      if (this.codeMirror) {
        this.codeMirror.refresh();
        this.codeMirror.setValue(currentCode.value);
        this.codeMirror.focus();
      } else {
        this.textarea.value = currentCode.value;
        this.textarea.focus();
      }

      this.setLanguage(adjustLanguage(currentCode.language));
    }
  }, {
    key: "setLanguage",
    value: function setLanguage(language) {
      var codeblockLanguage = this.langs.find(function (item) {
        return item.value == language;
      });

      if (!codeblockLanguage) {
        if (this.codeMirror) {
          this.codeMirror.setOption('mode', 'text');
        }

        if (this.languageSelect) {
          this.languageSelect.selectedIndex = 0;
        }
      } else {
        this.language = codeblockLanguage.value;

        if (this.codeMirror) {
          this.codeMirror.setOption('mode', codeblockLanguage.mode);
        }

        if (this.languageSelect) {
          this.languageSelect.value = codeblockLanguage.value;
        }
      }
    }
  }, {
    key: "insertCodeBlock",
    value: function insertCodeBlock() {
      var _this2 = this;

      var editor = this.tinymceEditor;
      var code = this.getValue();
      editor.undoManager.transact(function () {
        var node = _this2.getSelectedCodeBlock();

        code = editor.dom.encode(code);
        code = _this2.language ? "<code class='".concat(_this2.language, "'>").concat(code, "</code>") : "<code>".concat(code, "</code>");

        if (node) {
          node.removeAttribute('class');
          node.setAttribute('data-language', _this2.language);
          node.innerHTML = code;
          editor.selection.select(node);
        } else {
          editor.insertContent("<pre id=\"__new\">".concat(code, "</pre>"));
          node = editor.$('#__new').removeAttr('id')[0];
          editor.selection.select(node);
        }

        _highlight["default"].highlightBlock(editor.$(node).find('code')[0]);
      });
    }
  }, {
    key: "getValue",
    value: function getValue() {
      return this.codeMirror ? this.codeMirror.getValue() : this.textarea.value;
    }
  }, {
    key: "getCurrentCode",
    value: function getCurrentCode() {
      var node = this.getSelectedCodeBlock();

      if (node) {
        return {
          value: node.textContent,
          language: node.getAttribute('data-language')
        };
      } else {
        return {
          value: this.tinymceEditor.selection.getContent({
            format: 'text'
          }),
          language: ''
        };
      }
    }
  }, {
    key: "getSelectedCodeBlock",
    value: function getSelectedCodeBlock() {
      if (!this.selectedNode) {
        var node = this.tinymceEditor.selection.getNode();

        if (node && node.nodeName == 'PRE') {
          this.selectedNode = node;
        }
      }

      return this.selectedNode;
    }
  }, {
    key: "onChange",
    value: function onChange(callback) {
      if (this.codeMirror) {
        this.codeMirror.on('change', function (doc) {
          callback(doc.getValue());
        });
      } else {
        this.textarea.addEventListener("keyup", function (e) {
          callback(e.target.value);
        });
      }
    }
  }]);

  return CodeEditor;
}();

var _default = CodeEditor;
exports["default"] = _default;